@@ -11,10 +11,11 @@ class APMReporter(BaseHTTPMiddleware):
         start_time = time.perf_counter()
         response = await call_next(request)
         process_time = (time.perf_counter() - start_time)*1000
+        client_ip = request.client_ip
 
         if isinstance(response.status_code, int):
-            await report_red(request.url.path, response.status_code, process_time)
+            await report_red(request.url.path, response.status_code, process_time,client_ip)
         else:
-            await report_red(request.url.path, 0, process_time)
+            await report_red(request.url.path, 0, process_time,client_ip)
 
         return response
